<?php
/*
Plugin Name: Tab Menu
Plugin URI: http://www.pierovdfn.it/redirect/plugin_tabmenu.html
Description: This plugin is a non-intrusive way to add class="sel" to a tab menu
Author: Piero VDFN
Version: 4.1
Author URI: http://www.pierovdfn.it/
*/ 

/**
 * This function finds our place in the blog
 *
 * @return string: The place
 */
function plugin_tabmenu_where() {
	global $fp_params;

	if(@$fp_params['cat'] === '0') {
		$fp_params['cat'] = 0;
	}

	switch(true) {
		case function_exists('contact_main'):
			$where = 'contact';
			break;

		case defined('MOD_ADMIN_PANEL'):
			$where = 'admin';
			break;

		case function_exists('login_validate'):
			$where = 'login';
			break;

		case !empty($fp_params['entry']):
			$where = 'entry';
			break;

		case !empty($fp_params['page']):
			$where = 'page';
			break;

		case !empty($fp_params['tag']):
			$where = 'tag';
			break;

		case !empty($fp_params['cat']):
			$where = 'category';
			break;

		case @$fp_params['paged']==1:
		case @$fp_params['cat'] === 0:
			$where = 'blogindex';
			break;

		case empty($fp_params):
			$where = 'index';
			break;

		default:
			$where = false;
	}

	return $where;
}

/**
 * This function is the callback for preg_replace_callback.
 *
 * @param array $args: The arguments of the regex.
 * @return string: The replacement
 */
function plugin_tabmenu_do($args) {
	// Init the position
	static $plugin_tabmenu = 0;
	if(empty($plugin_tabmenu)) {
		$plugin_tabmenu = plugin_tabmenu_where();
	}

	global $fp_params, $fp_config, $plugin_tabmenu_ok;

	// $plugin_tabmenu_ok allows to use different replacements
	if(empty($plugin_tabmenu_ok)) {
		$plugin_tabmenu_ok = ' class="sel"';
	}

	// The replacements for found or not the position
	$ok = $args[1] . $plugin_tabmenu_ok . $args[3];
	$fail = $args[1] . $args[3];

	// Obtain the position
	$e = explode(':', $args[2], 2);

	// Params
	if($e[0] == 'params' || $e[0] == 'fpparams' || $e[0] == 'fp_params') {
		$par = utils_kexplode($e[1], '=&', false);

		if(isset($par['x'])) {
			$par = array_merge($par, utils_kexplode($par['x'], ':;', false));
		}

		return ($par == $fp_params) ? $ok : $fail;
	} else {
	// Fixed position

		// Synonims
		$a = array(
			'index' => array('index'),
			'blogindex' => array('blogindex', 'blog'),
			'entry' => array('entry', 'post'),
			'page' => array('static', 'page'),
			'category' => array('category', 'cat'),
			'tag' => array('tag'),
			'contact' => array('contact'),
			'admin' => array('admin', 'adminpanel'),
			'login' => array('login', 'logout'),
		);

		// Only when blog coincides with index merge them
		if(empty($fp_config['general']['startpage'])) {
			$a['index'] += $a['blogindex'];
			$a['blogindex'] = $a['index'];
		}

		// We aren't where $e[0] says, so stop here with $fail
		if(@!in_array($e[0], $a[$plugin_tabmenu])) {
			return $fail;
		}

		// Some cases have more parameters
		switch($plugin_tabmenu) {
			case 'category':
				if(!is_numeric($e[1])) {
					$e[1]=array_search($e[1], entry_categories_get('defs'));
				}

				return ($e[1] == $fp_params['cat']) ? $ok : $fail;
				break;

			case 'entry':
				if(strlen($e[1])==6) {
					// YYMMDD-HHMMSS form without "entry"
					$e[1] = 'entry' . $e[1];
				}
			// Nobreak: it was the same case.
			case 'tag':
			case 'page':
				return ($e[1]==$fp_params[$plugin_tabmenu]) ? $ok : $fail;

			default:
				return $ok;
		}
	}
}

/**
 * This function is a callback for the hook the_content.
 *
 * @param string $string: The content of the entry/page
 * @return string: The modified content
 */
function plugin_tabmenu_replace($string) {
	global $plugin_tabmenu_ok;

	// We replace all {{TABCLASS}}
	$plugin_tabmenu_ok = ' class="sel"';
	$string=preg_replace_callback('/(.*){{TABCLASS:(.*)}}(.*)/mi', 'plugin_tabmenu_do', $string);

	// We replace all {{TABSELECT}}
	$plugin_tabmenu_ok = 'sel';
	$string=preg_replace_callback('/(.*){{TABSELECT:(.*)}}(.*)/mi', 'plugin_tabmenu_do', $string);

	return $string;
}
add_filter('the_content', 'plugin_tabmenu_replace', 5, 1);
